pub fn set_rate_limit(permits: i32, period: i32, unit: TimeUnit)Expand description
Set the number of requests allowed per a given time period.
For example, set_rate_limit(10, 60, TimeUnit::Seconds) will allow 10 requests per minute.
If a request is made while the limit is exceeded, the request will be queued and executed
once the period is complete.